#
# spec file for package vidcutter
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           vidcutter
Version:        3.2.0
Release:        3.2
Summary:        Video cutter and joiner
License:        GPL-3.0+
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://vidcutter.ozmartians.com/
Source0:        https://github.com/ozmartian/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE vidcutter-setup.patch
Patch0:         %{name}-setup.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       ffmpeg
Requires:       libmpv1
Requires:       mediainfo
Requires:       python3-qt5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Cross-platform Qt5 based app for quick and easy video trimming/splitting
and merging/joining for simple quick edits. FFmpeg drives the backend with
a stylishly hand edited Qt5 UI.

%prep
%setup -q
%patch0 -p1
# remove shebang
export _filelist="
videolist.py __init__.py videoslider.py __main__.py libs/videoservice.py libs/widgets.py
videotoolbar.py libs/mpv.py videoinfo.py updater.py videoframe.py videostyles.py about.py
videocutter.py"
for f in $_filelist; do
    sed -i -e "1d" vidcutter/${f}
done

%build
python3 setup.py build

%install
python3 setup.py install --root %{buildroot}
%fdupes -s %{buildroot}%{_datadir}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc LICENSE README.md
%{_bindir}/%{name}
%{python3_sitelib}/%{name}-%{version}-py*.egg-info/
%{python3_sitelib}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
%{_datadir}/icons/hicolor/22x22/apps/%{name}.png
%{_datadir}/icons/hicolor/24x24/apps/%{name}.png
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%{_datadir}/icons/hicolor/512x512/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/pixmaps/%{name}.svg

%changelog
* Tue May  9 2017 aloisio@gmx.com
- Update to version 3.2.0-1
  * dark and light themes; chosen in the new settings sub-menu
    found in the right-click menu or via menu toolbar icon
  * new settings sub-menu (right-click or menu toolbar icon).
    some blurb on the settings (since i am too lazy to produce a
    help file right now :-)
    + Themes = select from the new dark and light themes (requires
    app restart)
    + Keep individual clips = each clip made from the clip index,
    which are then merged to produce the final product, are not
    deleted at end of proceess. They can be found in the same
    folder as the final produced video file  with file name
    sequence 001....00n appended.
    + Use native dialogs = on by default; can switch off to not
    use your desktop manager's native file open/save dialogs and
    instead use a generic cross-platform version supplied by Qt
    framework.
    + Always on top = sets application window as the top-most
    window, avoiding others apps from displaying over the top of
    it.
    + Toolbar labels = self-explanatory; allows you to set the
    main toolbar labels to display beside icons (default), under
    icons or hidden from view.
    + Hardware decoding = on by default to make the most of your
    GPU hardware.
    Switch this off if you are experiencing problems with the
    video playback.
    This option doesn't affect video cutting itself and is
    primarily for playback.
    + Keep aspect ratio = as the title suggests, switching this
    off caues video fill the available frame space rather than
    maintain its intended ratio for viewport width and height.
    This option doesn't affect video cutting itself and is
    primarily for playback.
    + Zoom = zoom in video from half its original size and up to
    double. This option doesn't affect video cutting itself and
    is primarily for playback.
    + a few minor changes to keyboard shortcuts; check the keyboad
    shortcuts cheatsheet via right-click or toolbar menu options.
  * new app icon
  * improved timeline look + new slider image + remove awkward mouse
    cursor previously in use to standard pointing hand cursor which
    feels better IMHO.
  * new VidCutter project file format; this is the same as an EDL
    but includes the full path to the media file associated with it.
    These can be saved and opened after program launch to set you
    back to where you last were in a cutting project.
  * eeePC and better support for HiDPI
  * better handling of multistreamed video sources including VOB
    files; if the standard method of creation produces a 0 length
    file the app will now run it again using various other methods
    to achieve th desired result. all cases reported by users as
    bugs in this area are now working. In most cases you will
    continue to get back exactly what you put in (pardon the pun).
    some VOBs are problematic so until the UI is built to allow users
    finer control over the backend settings the app will continue to
    make its own best judgement on behalf of the user. so, in the
    worse case scenario you should now get back a valid video file
    instead of 0 length video, but it may only include a single
    audio track rather than all the tracks from the source. keep in
    mind that in these rare cases the app will choose the best
    quality audio/video track when it can only work with just the
    one stream. The next version will allow you to select which
    streams from source media to include in your final generated
    video file.
  * improved handling of corrupted media files. the app should now
    work with far more source files than before.
  * time counter widget created allowing manual entry of timecode.
    Just click on the time segment to edit and video will seek to
    that exact point OR use the up/down arrow controls to the right
    of the running time code, highlight the segment you wish to
    increase or decrease (i.e. hours, mins, secs, msecs)
  * new dark theme; app is now better integrated for those who
    prefer to work with the darker side of the force; configurable
    via new menu option
  * video zoom level option added; configurable via new menu option
  * "Check for updates..." now checks for the latest release version
    of the app via the GitHub API and alerts user accordingly.
    It only offers to take the user to the release page while also
    explaining to stick with distribution-specific packages if
    running on Linux. Automatic updates are a goal of the future
    but would only be for Windows, macOS and AppImage linux versions.
  * The app will automatically check for updates; it will do this
    weekly and only disturb the user if an update has been released
    AND it has been at least one week since the last time updates
    were checked for.
  * new startup graphic.
  * new look dialogs including updater and about.
  * application settings now saved across all platforms; this
    includes window state and geometry as well as new settings in
    the right-click context menu.
- Added vidcutter-rpmlintrc
* Tue Mar  7 2017 aloisio@gmx.com
- Update to version 3.0.1
  * added check mediainfo before running Media Information
    widget code, advise user it is missing if not installed
    and what to do next.... gracefully exit..
- Added mediainfo as runtime dependency
* Fri Mar  3 2017 aloisio@gmx.com
- Update to version 3.0.0
- Refreshed vidcutter-setup.patch
* Tue Feb 28 2017 aloisio@gmx.com
- Replaced python3-QtPy requirement with python3-qt5
* Wed Feb 22 2017 aloisio@gmx.com
- Added vidcutter-setup.patch (removes PyQt5 requirement
  and sets the proper doc path)
* Tue Feb 14 2017 aloisio@gmx.com
- Added name to Source0 tarball
- Corrected license
* Sun Feb  5 2017 mailaender@opensuse.org
- initial packaging of version 2.6.5
